import cv2

def apply_sharpening_filter(image, amount=1.0, radius=1, threshold=0):
    """
    

    Parameters
    ----------
    image : TYPE array
        Input image that we are going to filter.
    amount : TYPE float, optional
        Scale the mask by the specified amount. The default is 1.0.
    radius : TYPE int, optional
        Gaussian Kernel Size. The default is 1.
    threshold : TYPE int, optional
        Used for the mask to limit the sharpening effect. The default is 0.

    Returns
    -------
    sharpened : TYPE array
        Output filtered image.

    """
    # Apply a Gaussian blur to the image
    blurred = cv2.GaussianBlur(image, (0, 0), radius)
    
    # Calculate the difference between the original image and the blurred image
    mask = cv2.subtract(image, blurred)
    
    # Scale the mask by the specified amount
    mask = cv2.multiply(mask, amount)
    
    # Apply a threshold to the mask to limit the sharpening effect
    if threshold > 0:
        mask = cv2.threshold(mask, threshold, 255, cv2.THRESH_BINARY)[1]
    
    # Add the mask back to the original image
    sharpened = cv2.add(image, mask)
    
    return sharpened
