
import cv2
import numpy as np

def detect_polygons(image):
    """
    

    Parameters
    ----------
    image : TYPE array
        Input image where we are going to detect polygons from.

    Returns
    -------
    output : TYPE array
        Output image in grey scale where detected polygons are drawn.

    """
    # Convert the image to grayscale
    gray = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)

    # Apply a Gaussian blur to reduce noise
    blurred = cv2.GaussianBlur(gray, (5, 5), 0)

    # Threshold the image to create a binary image
    _, thresh = cv2.threshold(blurred, 60, 255, cv2.THRESH_BINARY)

    # Find contours in the binary image
    contours, _ = cv2.findContours(thresh, cv2.RETR_TREE, cv2.CHAIN_APPROX_SIMPLE)

    # Draw the detected polygons on the original image
    output = image.copy()
    for contour in contours:
        # Approximate the polygonal curves from the contours
        approx = cv2.approxPolyDP(contour, 0.01*cv2.arcLength(contour, True), True)

        # Draw the detected polygons with green color and thickness 2
        cv2.drawContours(output, [approx], 0, (0, 0, 255), 2)

    return output

