
import cv2
import numpy as np

def detect_rectangles(image):
    """
    

    Parameters
    ----------
    image : TYPE array
        Input image where we are going to detect rectangles from.

    Returns
    -------
    output : TYPE array
        Output image in grey scale where detected rectangles are drawn.

    """
    # Convert the image to grayscale
    gray = cv2.cvtColor(image, cv2.COLOR_BGR2GRAY)

    # Apply a Gaussian blur to reduce noise
    blurred = cv2.GaussianBlur(gray, (5, 5), 0)

    # Apply Canny edge detection to highlight edges
    edges = cv2.Canny(blurred, 50, 150)

    # Find contours in the edge image
    contours, hierarchy = cv2.findContours(edges, cv2.RETR_EXTERNAL, cv2.CHAIN_APPROX_SIMPLE)

    # Loop over the contours and find rectangles
    rectangles = []
    for contour in contours:
        perimeter = cv2.arcLength(contour, True)
        approx = cv2.approxPolyDP(contour, 0.02 * perimeter, True)
        if len(approx) == 4:
            rectangles.append(approx)

    # Draw the rectangles on the original image
    output = image.copy()
    cv2.drawContours(output, rectangles, -1, (255, 0, 0), 2)

    return output

