import cv2

def mask_image(image, mask):
    """
    

    Parameters
    ----------
    image : TYPE array
        Input image that we are going to mask.
    mask : TYPE array
        Mask of the same dimension than image that is used to select the 
        visible part of the image. Color is visible, white is not visible

    Returns
    -------
    masked_image : TYPE array
        Output image that has been masked.

    """
    # Convert the mask to a binary image
    binary_mask = cv2.cvtColor(mask, cv2.COLOR_BGR2GRAY)
    _, binary_mask = cv2.threshold(binary_mask, 0, 255, cv2.THRESH_BINARY)

    # Invert the binary mask
    binary_mask_inv = cv2.bitwise_not(binary_mask)

    # Split the image into color channels
    b, g, r = cv2.split(image)

    # Apply the binary mask to each color channel
    b_masked = cv2.bitwise_and(b, b, mask=binary_mask_inv)
    g_masked = cv2.bitwise_and(g, g, mask=binary_mask_inv)
    r_masked = cv2.bitwise_and(r, r, mask=binary_mask_inv)

    # Merge the masked color channels back into a single image
    masked_image = cv2.merge((b_masked, g_masked, r_masked))

    return masked_image
