import cv2

def zoom_image(image, zoom_factor, center_x, center_y):
    """
    

    Parameters
    ----------
    image : TYPE array
        Input image where we are going to zoom.
    zoom_factor : TYPE float
        Factor used to zoom.
    center_x : TYPE int
        Abcissa of the center of the zoom.
    center_y : TYPE int
        Ordenate of the center of the zoom.

    Raises
    ------
    ValueError
        If center_x or center_y are unuseable.

    Returns
    -------
    zoomed : TYPE array
        Output zoomed image.

    """
    # Get the dimensions of the image
    height, width, channels = image.shape

    # Calculate the new dimensions of the zoomed image
    new_width = int(width * zoom_factor)
    new_height = int(height * zoom_factor)

    # Calculate the new coordinates of the center point after zooming
    new_center_x = int(center_x * zoom_factor)
    new_center_y = int(center_y * zoom_factor)

    # Calculate the x and y coordinates of the top-left corner of the zoomed image
    x = new_center_x - int(new_width / 2)
    y = new_center_y - int(new_height / 2)

    # Check if the zoomed image is within the bounds of the original image
    if x < 0 or y < 0 or x + new_width > width or y + new_height > height:
        raise ValueError("Zoomed image is out of bounds")

    # Crop the image to the zoomed ROI and resize to the original image size
    zoomed = cv2.resize(image[y:y+new_height, x:x+new_width], (width, height))

    return zoomed